@@ -1,5 +1,7 @@
 from abc import ABCMeta
 from abc import abstractmethod
+from typing import Dict
+from typing import List
 
 from .base_spider import BaseSpider
 
@@ -8,6 +10,5 @@ class SingleSpider(BaseSpider, metaclass=ABCMeta):
     """简单单线程爬虫的抽象基类"""
 
     @abstractmethod
-    def running(self, **params):
+    def running(self, **params) -> List[Dict]:
         """执行爬虫"""
-
